#
# spec file for package zabbix
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define server_user  zabbixs
%define server_group zabbixs
# keep zabbix user for backwards compatibility of agent
%define agent_user   zabbix
%define agent_group  zabbix
%define SUSEfirewall_services_dir %{_sysconfdir}/sysconfig/SuSEfirewall2.d/services
Name:           zabbix
Version:        4.0.37
Release:        lp153.2.3.1
Summary:        Distributed monitoring system
License:        GPL-2.0-or-later
Group:          System/Monitoring
URL:            http://www.zabbix.com
Source0:        https://cdn.zabbix.com/zabbix/sources/stable/4.0/zabbix-%{version}.tar.gz
Source1:        rn4.0.0.html
Source2:        zabbix-tmpfiles.conf
Source3:        zabbix-java-gateway.sh
Source4:        zabbix-logrotate.in
Source5:        apache2-zabbix.conf
Source6:        README.SUSE
Source7:        zabbix-server.firewall
Source8:        zabbix-agentd.firewall
Source9:        zabbix-proxy.firewall
Source10:       zabbix-java-gateway.firewall
Source11:       zabbix-proxy.service
Source12:       zabbix-agentd.service
Source13:       zabbix-server.service
Source14:       zabbix-java-gateway.service
Source15:       README-SSL.SUSE
# PATCH-FIX-UPSTREAM zabbix-3.0.25-new-m4-pgsql.patch fix for opensuse issue caused/solved by bnc#1120035
Patch0:         zabbix-3.0.25-new-m4-pgsql.patch
BuildRequires:  apache-rpm-macros
BuildRequires:  apache2-devel
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  java-devel >= 1.6
BuildRequires:  libmysqlclient-devel
BuildRequires:  libtool
BuildRequires:  logrotate
BuildRequires:  net-snmp-devel
BuildRequires:  openldap2-devel
BuildRequires:  pkgconfig
BuildRequires:  systemd-rpm-macros
BuildRequires:  unixODBC-devel
BuildRequires:  update-alternatives
BuildRequires:  pkgconfig(OpenIPMI)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libevent)
BuildRequires:  pkgconfig(libpcre)
BuildRequires:  pkgconfig(libpq)
BuildRequires:  pkgconfig(libssh2)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(zlib)
%{?systemd_requires}

%description
Zabbix is a distributed monitoring system.

Zabbix is software that monitors numerous parameters of a network and the
health and integrity of servers. Zabbix uses a flexible notification mechanism
that allows users to configure e-mail based alerts for virtually any event.
This allows a fast reaction to server problems. Zabbix offers excellent
reporting and data visualisation features based on the stored data. This makes
Zabbix ideal for capacity planning.

Zabbix supports both polling and trapping. All Zabbix reports and statistics,
as well as configuration parameters, are accessed through a web-based frontend.
A web-based frontend ensures that the status of your network and the health of
your servers can be assessed from any location. Properly configured, Zabbix can
play an important role in monitoring IT infrastructure. This is equally true
for small organisations with a few servers and for large companies with a
multitude of servers.

%package agent
Summary:        Local resource monitor agent for Zabbix
Group:          System/Monitoring
Requires:       logrotate
Requires(pre):  %fillup_prereq
Requires(pre):  shadow
Conflicts:      zabbix-agent

%description agent
The Zabbix agent monitors local resources and relays information to the server.

%package server
Summary:        System files for the Zabbix server
Group:          System/Monitoring
Requires:       fping
Requires:       logrotate
Requires:       update-alternatives
Requires:       zabbix_server_binary = %{version}-%{release}
Requires(pre):  %fillup_prereq
Requires(pre):  shadow
Conflicts:      zabbix-server

%description server
The Zabbix server component.

%package proxy
Summary:        System files for the Zabbix proxy
Group:          System/Monitoring
Requires:       fping
Requires:       logrotate
Requires:       update-alternatives
Requires:       zabbix_proxy_binary = %{version}-%{release}
Requires(pre):  %fillup_prereq
Requires(pre):  shadow
Conflicts:      zabbix-proxy

%description proxy
The Zabbix proxy component.

%package phpfrontend
Summary:        Zabbix web frontend (php)
Group:          Productivity/Networking/Web/Frontends
Requires:       apache2
Requires:       php7
Requires:       php7-bcmath
Requires:       php7-ctype
Requires:       php7-gd
Requires:       php7-gettext
Requires:       php7-ldap
Requires:       php7-mbstring
Requires:       php7-sockets
Requires:       php7-xmlreader
Requires:       php7-xmlwriter
Suggests:       php7-mysqli
Suggests:       php7-pgsql
Conflicts:      zabbix-phpfrontend

%description phpfrontend
The Zabbix PHP frontend allows access via standard web browsers.

NOTE: You still have to install the PHP package which contains your db driver!

%package server-mysql
Summary:        Zabbix server with MySQL support
Group:          System/Monitoring
Requires:       %{name}-server = %{version}-%{release}
Requires:       mariadb
Requires(post): update-alternatives
Requires(postun):update-alternatives
Conflicts:      zabbix-server-mysql
Provides:       %{name} = %{version}-%{release}
Provides:       zabbix_server_binary = %{version}-%{release}

%description server-mysql
The Zabbix server compiled with MySQL support.

%package server-postgresql
Summary:        Zabbix server with PostgreSQL support
Group:          System/Monitoring
Requires:       %{name}-server = %{version}-%{release}
Requires:       postgresql
Requires(post): update-alternatives
Requires(postun):update-alternatives
Conflicts:      zabbix-server-postgresql
Provides:       %{name} = %{version}-%{release}
Provides:       zabbix_server_binary = %{version}-%{release}

%description server-postgresql
The Zabbix server compiled with PostgreSQL support.

%package proxy-mysql
Summary:        Zabbix proxy with MySQL support
Group:          System/Monitoring
Requires:       %{name}-proxy = %{version}-%{release}
Requires:       mariadb
Requires(post): update-alternatives
Requires(postun):update-alternatives
Conflicts:      zabbix-proxy-mysql
Provides:       %{name} = %{version}-%{release}
Provides:       zabbix_proxy_binary = %{version}-%{release}

%description proxy-mysql
The Zabbix proxy compiled with MySQL support.

%package proxy-postgresql
Summary:        Zabbix proxy with PostgreSQL support
Group:          System/Monitoring
Requires:       %{name}-proxy = %{version}-%{release}
Requires:       postgresql
Requires(post): update-alternatives
Requires(postun):update-alternatives
Conflicts:      zabbix-proxy-postgresql
Provides:       %{name} = %{version}-%{release}
Provides:       zabbix_proxy_binary = %{version}-%{release}

%description proxy-postgresql
The Zabbix proxy compiled with PostgreSQL support.

%package proxy-sqlite
Summary:        Zabbix proxy with SQLite support
Group:          System/Monitoring
Requires:       %{name}-proxy = %{version}-%{release}
Requires(post): update-alternatives
Requires(postun):update-alternatives
Conflicts:      zabbix-proxy-sqlite
Provides:       %{name} = %{version}-%{release}
Provides:       zabbix_proxy_binary = %{version}-%{release}

%description proxy-sqlite
The Zabbix proxy compiled with SQLite support.

%package java-gateway
Summary:        Zabbix Java gateway
Group:          System/Monitoring
Requires:       jre
Requires(pre):  shadow
Conflicts:      zabbix-java-gateway
Provides:       %{name} = %{version}-%{release}

%description java-gateway
JMX monitoring can be used to monitor JMX counters of a Java
application. To retrieve the value of a particular JMX counter on a
host, the Zabbix server queries the Zabbix Java gateway, which in
turn uses the JMX management API to query the application of interest
remotely.

%prep
%setup -q -n zabbix-%{version}
%patch0

cp %{SOURCE6} .
# fix source & config files to respect adapted names
for file in src/zabbix_java/settings.sh src/zabbix_java/lib/logback.xml %{SOURCE3} conf/*.conf  misc/init.d/suse/*/zabbix_* src/zabbix_server/server.c \
	src/zabbix_server/alerter/alerter.c src/zabbix_agent/zbxconf.c src/zabbix_agent/zabbix_agentd.c src/zabbix_proxy/proxy.c ChangeLog; do
	sed -i -e "s@/home/zabbix/bin@%{_bindir}@g" \
		-e "s@^[# ]*PidFile=/tmp/zabbix_@PidFile=%{_rundir}/%{agent_user}/zabbix_@g" \
		-e "s@^[# ]*LogFile=/tmp/zabbix_@LogFile=%{_localstatedir}/log/%{agent_user}/zabbix_@g" \
		-e "s@^[# ]*DBSocket=/tmp/mysql.sock@DBSocket=%{_rundir}/mysql/mysql.sock@g" \
		-e "s@^[# ]*SocketDir=/tmp@SocketDir=%{_rundir}/%{agent_user}@g" \
		-e "s@DBUser=root@DBUser=zabbix@g" \
		-e "s@^[# ]*DBPassword=.*@DBPassword=zabbix@g" \
		-e "s@Hostname=Zabbix Server@Hostname=Zabbix_Server@" \
		-e "s@GW_PID:=%{_localstatedir}/run/zabbix/zabbix-java-gateway.pid@GW_PID:=%{_rundir}/%{server_user}/zabbix-java-gateway.pid@g" \
		-e "s@GW_LOGFILE:=%{_localstatedir}/log/zabbix/zabbix-java-gateway.log@GW_LOGFILE:=%{_localstatedir}/log/%{server_user}/zabbix-java-gateway.log@g" $file
done

# fix server, java and proxy (again) config for log and run location...
for file in src/zabbix_java/settings.sh conf/zabbix_proxy.conf conf/zabbix_server.conf ; do
	sed -i -e "s#^[# ]*LogFile=%{_localstatedir}/log/.*/zabbix_#LogFile=%{_localstatedir}/log/%{server_user}/zabbix_#g" \
		-e "s#^[# ]*PidFile=%{_rundir}/.*/zabbix_#PidFile=%{_rundir}/%{server_user}/zabbix_#g" \
		-e "s#^[# ]*SocketDir=%{_rundir}/%{agent_user}#SocketDir=%{_rundir}/%{server_user}#g" \
		-e 's#PID_FILE="%{_rundir}/.*/zabbix_#PID_FILE="%{_rundir}/%{server_user}/zabbix_#g' $file
done

# fix db content to respect adapted names and suse naming conventions
for file in database/*/data.sql; do
	sed -i -e "s#syslogd#syslog-ng#g" \
		-e "s#Syslogd#Syslog-ng#g" \
		-e "s#httpd#httpd2-prefork#g" $file
done
##### Fix for date time macros
REF_DATE=$(LANG=C date -r configure +"%%b %%d %%Y")
REF_TIME=$(LANG=C date -r configure +"%%H:%%M:%%S")
sed -i -e "s/__DATE__/\"${REF_DATE}\"/g" -e "s/__TIME__/\"${REF_TIME}\"/g" src/libs/zbxcommon/str.c
#####
##### Fix location of zabbix java gateway location
sed -ri 's@^(ZABBIX_JAVA_CONF=.\{ZABBIX_JAVA_CONF:=).*@\1%{_sysconfdir}/zabbix/zabbix-java-gateway.conf}@g' %{SOURCE3}

# Remove prebuilt Windows binaries
rm -rf bin

#make separate directories for each config
cd ..
cp -r zabbix-%{version} zabbix-%{version}-postgresql
cp -r zabbix-%{version} zabbix-%{version}-sqlite
cd -

%build
ZABBIX_BASIC_CONFIG="--enable-proxy --enable-server --enable-agent  --sysconfdir=%{_sysconfdir}/zabbix \
                     --with-openipmi --enable-java --enable-ipv6 --with-ssh2 --with-ldap --with-unixodbc \
                     --with-libcurl --with-net-snmp --with-libxml2 --with-openssl --with-libpcre --with-libevent"

# configure MySQL repo (here)
autoreconf -fvi
%configure $ZABBIX_BASIC_CONFIG --with-mysql --without-postgresql --without-sqlite3
make %{?_smp_mflags}

# configure PostgreSQL repo
cd ../zabbix-%{version}-postgresql
autoreconf -fvi
%configure $ZABBIX_BASIC_CONFIG --with-postgresql --without-mysql --without-sqlite3
make %{?_smp_mflags}
cd -

# configure SQLite repo
cd ../zabbix-%{version}-sqlite
autoreconf -fvi
%configure $ZABBIX_BASIC_CONFIG --disable-server --enable-proxy --with-sqlite3 --without-postgresql --without-mysql
make %{?_smp_mflags}
cd -

%install
# install the binaries

%make_install -C ../zabbix-%{version}-sqlite
mv %{buildroot}%{_sbindir}/zabbix_proxy %{buildroot}%{_sbindir}/zabbix_proxy-sqlite

%make_install -C ../zabbix-%{version}-postgresql
mv %{buildroot}%{_sbindir}/zabbix_server %{buildroot}%{_sbindir}/zabbix_server-postgresql
mv %{buildroot}%{_sbindir}/zabbix_proxy %{buildroot}%{_sbindir}/zabbix_proxy-postgresql

%make_install
mv %{buildroot}%{_sbindir}/zabbix_server %{buildroot}%{_sbindir}/zabbix_server-mysql
mv %{buildroot}%{_sbindir}/zabbix_proxy %{buildroot}%{_sbindir}/zabbix_proxy-mysql

mv %{buildroot}%{_bindir}/zabbix_sender %{buildroot}%{_sbindir}/zabbix_sender

# create directory structure
install -d %{buildroot}%{_localstatedir}/log/%{server_user}
install -d %{buildroot}%{_localstatedir}/log/%{agent_user}

# move java gateway files
mkdir -p %{buildroot}/%{_prefix}/lib/zabbix-java-gateway
mv %{buildroot}%{_sbindir}/zabbix_java/lib/*.jar %{buildroot}%{_prefix}/lib/zabbix-java-gateway
mv %{buildroot}%{_sbindir}/zabbix_java/bin/*.jar %{buildroot}%{_prefix}/lib/zabbix-java-gateway
mv %{buildroot}%{_sbindir}/zabbix_java/settings.sh %{buildroot}%{_sysconfdir}/zabbix/zabbix-java-gateway.conf
mv %{buildroot}%{_sbindir}/zabbix_java/lib/logback.xml %{buildroot}%{_sysconfdir}/zabbix/zabbix-java-gateway-log.xml
install -m 0755 %{SOURCE3} %{buildroot}%{_bindir}/zabbix-java-gateway
# we do not need the rest
rm -r %{buildroot}%{_sbindir}/zabbix_java

# install the php frontend
mkdir -p %{buildroot}%{_datadir}/zabbix
cp -r frontends/php/* %{buildroot}%{_datadir}/zabbix
install -Dm 0644 %{SOURCE5} %{buildroot}%{apache_sysconfdir}/conf.d/zabbix.conf
# remove .htaccess files as access rules are moved to zabbix.conf
find %{buildroot}%{_datadir}/zabbix -name .htaccess -exec rm -v {} \;

# Install log rotation
mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d
sed -e 's|COMPONENT|agentd|g; s|USER|zabbix|g' %{SOURCE4} > \
     %{buildroot}%{_sysconfdir}/logrotate.d/%{name}-agent
sed -e 's|COMPONENT|server|g; s|USER|zabbixs|g' %{SOURCE4} > \
     %{buildroot}%{_sysconfdir}/logrotate.d/%{name}-server
sed -e 's|COMPONENT|proxy|g; s|USER|zabbixs|g' %{SOURCE4} > \
     %{buildroot}%{_sysconfdir}/logrotate.d/%{name}-proxy

%fdupes %{buildroot}

# install firewall description files for SLE 12 / Leap 42
%if 0%{?suse_version} < 1500
install -Dm 0644 %{SOURCE7} %{buildroot}%{SUSEfirewall_services_dir}/zabbix_server
install -Dm 0644 %{SOURCE8} %{buildroot}%{SUSEfirewall_services_dir}/zabbix_agentd
install -Dm 0644 %{SOURCE9} %{buildroot}%{SUSEfirewall_services_dir}/zabbix_proxy
install -Dm 0644 %{SOURCE10} %{buildroot}%{SUSEfirewall_services_dir}/zabbix-java-gateway
%endif

# install systemd unit files
install -Dm 0644 %{SOURCE11} %{buildroot}%{_unitdir}/zabbix_proxy.service
install -Dm 0644 %{SOURCE12} %{buildroot}%{_unitdir}/zabbix_agentd.service
install -Dm 0644 %{SOURCE13} %{buildroot}%{_unitdir}/zabbix_server.service
install -Dm 0644 %{SOURCE14} %{buildroot}%{_unitdir}/zabbix-java-gateway.service
install -dm 0755 %{buildroot}/%{_unitdir}/zabbix_server.service.requires
install -dm 0755 %{buildroot}/%{_unitdir}/zabbix_proxy.service.requires

# set the rc sym links
ln -s service %{buildroot}%{_sbindir}/rczabbix_agentd
ln -s service %{buildroot}%{_sbindir}/rczabbix_server
ln -s service %{buildroot}%{_sbindir}/rczabbix_proxy
ln -s service %{buildroot}%{_sbindir}/rczabbix-java-gateway

# this stupidity is required because i do not wanna create separate zabbix-common
# in case i ever do it will put it under one scope...
install -Dm 0644 %{SOURCE2} %{buildroot}%{_tmpfilesdir}/zabbix_agentd.conf
# here I suppose server_user==server_group (and agent_user==agent_group, which is for compatibility reasons)
sed -i 's@%{agent_user}@%{server_user}@g' %{SOURCE2}
install -Dm 0644 %{SOURCE2} %{buildroot}%{_tmpfilesdir}/zabbix_server.conf
install -Dm 0644 %{SOURCE2} %{buildroot}%{_tmpfilesdir}/zabbix_proxy.conf
install -Dm 0644 %{SOURCE2} %{buildroot}%{_tmpfilesdir}/zabbix-java-gateway.conf
###################################################################################

# update-alternatives
install -d -m 0755 %{buildroot}%{_sysconfdir}/alternatives
touch -r /bin/true %{buildroot}%{_sysconfdir}/alternatives/zabbix_server
touch -r /bin/true %{buildroot}%{_sysconfdir}/alternatives/zabbix_proxy
ln -s %{_sysconfdir}/alternatives/zabbix_server %{buildroot}%{_sbindir}/zabbix_server
ln -s %{_sysconfdir}/alternatives/zabbix_proxy %{buildroot}%{_sbindir}/zabbix_proxy

# set links zabbix-* -> zabbix_* (to avoid confusion among users)
ln -s %{_sbindir}/zabbix_server %{buildroot}%{_sbindir}/zabbix-server
ln -s %{_sbindir}/zabbix_server %{buildroot}%{_sbindir}/zabbix-proxy
ln -s %{_sbindir}/zabbix_agentd %{buildroot}%{_sbindir}/zabbix-agentd
ln -s %{_sbindir}/zabbix_sender %{buildroot}%{_sbindir}/zabbix-sender
ln -s %{_bindir}/zabbix_get %{buildroot}%{_bindir}/zabbix-get

# Remove Makefiles from database directories so they don't get picked up by %%doc
rm database/*/Makefile*

# Release Notes - what has changed against Zabbix 3.x
cp %{SOURCE1} .

# SSL README
cp %{SOURCE15} .

%pre server
# Server daemon
%{_bindir}/getent group %{server_group} >/dev/null || %{_sbindir}/groupadd -r %{server_group}
%{_bindir}/getent passwd %{server_user} >/dev/null || %{_sbindir}/useradd -r -d %{_localstatedir}/lib/%{server_user} -s /bin/false -c "Zabbix Server Daemon" -g %{server_group} %{server_user}
%service_add_pre zabbix_server.service
exit 0

%pre proxy
# Proxy daemon
%{_bindir}/getent group %{server_group} >/dev/null || %{_sbindir}/groupadd -r %{server_group}
%{_bindir}/getent passwd %{server_user} >/dev/null || %{_sbindir}/useradd -r -d %{_localstatedir}/lib/%{server_user} -s /bin/false -c "Zabbix Proxy Daemon" -g %{server_group} %{server_user}
%service_add_pre zabbix_proxy.service
exit 0

%pre agent
# Agent daemon
%{_bindir}/getent group %{agent_group} >/dev/null || %{_sbindir}/groupadd -r %{agent_group}
%{_bindir}/getent passwd %{agent_user} >/dev/null || %{_sbindir}/useradd -r -d %{_localstatedir}/lib/%{agent_user} -s /bin/false -c "Zabbix Agent Daemon" -g %{agent_group} %{agent_user}
%service_add_pre zabbix_agentd.service
exit 0

%pre java-gateway
# Java daemon
%{_bindir}/getent group %{server_group} >/dev/null || %{_sbindir}/groupadd -r %{server_group}
%{_bindir}/getent passwd %{server_user} >/dev/null || %{_sbindir}/useradd -r -d %{_localstatedir}/lib/%{server_user} -s /bin/false -c "Zabbix Java Daemon" -g %{server_group} %{server_user}
%service_add_pre zabbix-java-gateway.service
exit 0

%post server
%service_add_post zabbix_server.service
%tmpfiles_create %{_tmpfilesdir}/zabbix_server.conf
echo "Please read %{_docdir}/%{name}-server/README-SSL.SUSE to set up SSL on Zabbix server."

%post proxy
%service_add_post zabbix_proxy.service
%tmpfiles_create %{_tmpfilesdir}/zabbix_proxy.conf
echo "Please read %{_docdir}/%{name}-proxy/README-SSL.SUSE to set up SSL on Zabbix proxy."

%post java-gateway
%service_add_post zabbix-java-gateway.service
%tmpfiles_create %{_tmpfilesdir}/zabbix-java-gateway.conf

%post agent
%service_add_post zabbix_agentd.service
%tmpfiles_create %{_tmpfilesdir}/zabbix_agentd.conf
echo "Please read %{_docdir}/%{name}-agent/README-SSL.SUSE to set up SSL on Zabbix agent."

%post server-mysql
%{_sbindir}/update-alternatives --install %{_sbindir}/zabbix_server zabbix_server %{_sbindir}/zabbix_server-mysql 12

%post server-postgresql
%{_sbindir}/update-alternatives --install %{_sbindir}/zabbix_server zabbix_server %{_sbindir}/zabbix_server-postgresql 11

%post proxy-mysql
%{_sbindir}/update-alternatives --install %{_sbindir}/zabbix_proxy zabbix_proxy %{_sbindir}/zabbix_proxy-mysql 12

%post proxy-postgresql
%{_sbindir}/update-alternatives --install %{_sbindir}/zabbix_proxy zabbix_proxy %{_sbindir}/zabbix_proxy-postgresql 11

%post proxy-sqlite
%{_sbindir}/update-alternatives --install %{_sbindir}/zabbix_proxy zabbix_proxy %{_sbindir}/zabbix_proxy-sqlite 10

%preun server
%service_del_preun zabbix_server.service

%preun proxy
%service_del_preun zabbix_proxy.service

%preun java-gateway
%service_del_preun zabbix-java-gateway.service

%preun agent
%service_del_preun zabbix_agentd.service

%postun server
%service_del_postun zabbix_server.service

%postun proxy
%service_del_postun zabbix_proxy.service

%postun java-gateway
%service_del_postun zabbix-java-gateway.service

%postun agent
%service_del_postun zabbix_agentd.service

%postun server-mysql
if [ "$1" = 0 ] ; then
	%{_sbindir}/update-alternatives --remove zabbix_server %{_sbindir}/zabbix_server-mysql
fi

%postun server-postgresql
if [ "$1" = 0 ] ; then
	%{_sbindir}/update-alternatives --remove zabbix_server %{_sbindir}/zabbix_server-postgresql
fi

%postun proxy-mysql
if [ "$1" = 0 ] ; then
	%{_sbindir}/update-alternatives --remove zabbix_proxy %{_sbindir}/zabbix_proxy-mysql
fi

%postun proxy-postgresql
if [ "$1" = 0 ] ; then
        %{_sbindir}/update-alternatives --remove zabbix_proxy %{_sbindir}/zabbix_proxy-postgresql
fi

%postun proxy-sqlite
if [ "$1" = 0 ] ; then
        %{_sbindir}/update-alternatives --remove zabbix_proxy %{_sbindir}/zabbix_proxy-sqlite
fi

%files server
%doc AUTHORS ChangeLog database/ibm_db2 database/mysql database/oracle database/postgresql database/sqlite3 rn4.0.0.html README-SSL.SUSE
%if 0%{?suse_version} < 1500
%config %{SUSEfirewall_services_dir}/zabbix_server
%endif
%dir %{_sysconfdir}/zabbix
%config(noreplace) %attr(0640, root, %{server_group}) %{_sysconfdir}/zabbix/zabbix_server.conf
%{_bindir}/zabbix_get
%{_bindir}/zabbix-get
%{_sbindir}/zabbix_server
%{_sbindir}/zabbix-server
%{_sbindir}/rczabbix_server
%attr(0770,root,%{server_group}) %dir %{_localstatedir}/log/%{server_user}
%ghost %attr(0770,root,%{server_group}) %dir %{_rundir}/%{server_user}
%{_mandir}/man1/zabbix_get.1%{?ext_man}
%{_mandir}/man8/zabbix_server.8%{?ext_man}
%{_unitdir}/zabbix_server.service
%{_unitdir}/zabbix_server.service.requires
%{_tmpfilesdir}/zabbix_server.conf
%ghost %{_sysconfdir}/alternatives/zabbix_server
%ghost %{_sysconfdir}/alternatives/zabbix_server.service
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}-server

%files proxy
%doc README-SSL.SUSE
%if 0%{?suse_version} < 1500
%config %{SUSEfirewall_services_dir}/zabbix_proxy
%endif
%{_sbindir}/zabbix_proxy
%{_sbindir}/zabbix-proxy
%{_sbindir}/rczabbix_proxy
%dir %{_sysconfdir}/zabbix
%config(noreplace) %attr(0640, root, %{server_group}) %{_sysconfdir}/zabbix/zabbix_proxy.conf
%attr(0770,root,%{server_group}) %dir %{_localstatedir}/log/%{server_user}
%ghost %attr(0770,root,%{server_group}) %dir %{_rundir}/%{server_user}
%{_mandir}/man8/zabbix_proxy.8%{?ext_man}
%{_unitdir}/zabbix_proxy.service
%{_unitdir}/zabbix_proxy.service.requires
%{_tmpfilesdir}/zabbix_proxy.conf
%ghost %{_sysconfdir}/alternatives/zabbix_proxy
%ghost %{_sysconfdir}/alternatives/zabbix_proxy.service
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}-proxy

%files agent
%doc README-SSL.SUSE
%if 0%{?suse_version} < 1500
%config %{SUSEfirewall_services_dir}/zabbix_agentd
%endif
%dir %{_sysconfdir}/zabbix
%config(noreplace) %attr(0640, root, %{agent_group}) %{_sysconfdir}/zabbix/zabbix_agent*.conf
%{_sbindir}/rczabbix_agentd
%{_sbindir}/zabbix_agentd
%{_sbindir}/zabbix-agentd
%{_sbindir}/zabbix_sender
%{_sbindir}/zabbix-sender
%attr(0770,root,%{agent_group}) %dir %{_localstatedir}/log/%{agent_user}
%ghost %attr(0770,root,%{agent_group}) %dir %{_rundir}/%{agent_user}
%{_mandir}/man8/zabbix_agentd.8%{?ext_man}
%{_mandir}/man1/zabbix_sender.1%{?ext_man}
%{_unitdir}/zabbix_agentd.service
%{_tmpfilesdir}/zabbix_agentd.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}-agent

%files phpfrontend
%doc README.SUSE
%dir %{apache_sysconfdir}
%dir %{apache_sysconfdir}/conf.d
%config(noreplace) %{apache_sysconfdir}/conf.d/zabbix.conf
%{_datadir}/zabbix

%files server-mysql
%{_sbindir}/zabbix_server-mysql
%{_sbindir}/zabbix_server
%ghost %{_sysconfdir}/alternatives/zabbix_server

%files server-postgresql
%{_sbindir}/zabbix_server-postgresql
%{_sbindir}/zabbix_server
%ghost %{_sysconfdir}/alternatives/zabbix_server

%files proxy-mysql
%{_sbindir}/zabbix_proxy-mysql
%{_sbindir}/zabbix_proxy
%ghost %{_sysconfdir}/alternatives/zabbix_proxy

%files proxy-postgresql
%{_sbindir}/zabbix_proxy-postgresql
%{_sbindir}/zabbix_proxy
%ghost %{_sysconfdir}/alternatives/zabbix_proxy

%files proxy-sqlite
%{_sbindir}/zabbix_proxy-sqlite
%{_sbindir}/zabbix_proxy
%ghost %{_sysconfdir}/alternatives/zabbix_proxy

%files java-gateway
%if 0%{?suse_version} < 1500
%config %{SUSEfirewall_services_dir}/zabbix-java-gateway
%endif
%dir %{_sysconfdir}/zabbix
%config(noreplace) %attr(0640, root, %{server_group}) %{_sysconfdir}/zabbix/zabbix-java-gateway.conf
%config(noreplace) %attr(0640, root, %{server_group}) %{_sysconfdir}/zabbix/zabbix-java-gateway-log.xml
%dir %{_prefix}/lib/zabbix-java-gateway
%{_bindir}/zabbix-java-gateway
%{_prefix}/lib/zabbix-java-gateway/zabbix-java-gateway-%{version}%{?rclevel}.jar
%{_prefix}/lib/zabbix-java-gateway/android-json-4.3_r3.1.jar
%{_prefix}/lib/zabbix-java-gateway/slf4j-api-1.7.32.jar
%{_prefix}/lib/zabbix-java-gateway/logback-core-1.2.9.jar
%{_prefix}/lib/zabbix-java-gateway/logback-classic-1.2.9.jar
%{_sbindir}/rczabbix-java-gateway
%attr(0770,root,%{server_group}) %dir %{_localstatedir}/log/%{server_user}
%ghost %attr(0770,root,%{server_group}) %dir %{_rundir}/%{server_user}
%{_unitdir}/zabbix-java-gateway.service
%{_tmpfilesdir}/zabbix-java-gateway.conf

%changelog
* Sat Jan 22 2022 Boris Manojlovic <boris@steki.net>
- updated to latest realease 4.0.37
- patching CVE-2022-23134 ( bsc#1194681 )
- New Features and Improvements
  + ZBXNEXT-6809 Changed behavior of the vmware event log, the 'skip'
    option of the new item resets the VMware event cache
- Bug Fixes
  + ZBX-20382 	Updated jquery version
  + ZBX-20383 	Updated logback-core, logback-classic and slf4j-api jars to the latest stable versions
  + ZBX-20384 	Fixed possibility to view setup pages by non-superadmin if config already file exists
- Bug Fixes
  + ZBX-19926 	Fixed Zabbix agent crashing when reading event log on Windows Server 2022
  + ZBX-20032 	Fixed server crash when restarting monitored vmware vc
  + ZBX-19872 	Removed redundant escaping in XML data of HTTP agent POST request
- Bug Fixes
  + ZBX-19428 	Fixed high CPU usage and preprocessing workers exiting with
    timeout when starting numerous poller, trapper and discoverer processes
  + ZBX-19510 	Fixed re-reading of old Windows events for various Windows event system synchronization problems
  + ZBX-19457 	Fixed failed query when updating application names longer than 255 characters
* Tue Jan 11 2022 Johannes Segitz <jsegitz@suse.com>
- Added hardening to systemd service(s) (bsc#1181400). Modified:
  * zabbix-java-gateway.service
* Tue Oct  5 2021 Boris Manojlovic <boris@steki.net>
- updated to latest release 4.0.34
- New Features and Improvements
  + ZBXNEXT-6852 Updated localization for Zabbix Support URL
- Bug Fixes
  + ZBX-19814 Added ignoring final result in case if fping quits on a signal
  + ZBX-19931 Fixed crash on big-endian systems when processing history
  + ZBX-19580 Fixed date format mismatch in UI elements that are loaded via JavaScript
  + ZBX-19236 Fixed task manager constantly busy with close_problem task
    if trigger no longer exists but event still exist
  + ZBX-19857 Dropped support for the non-working option "with_gui_access"
    in the usergroup.get() method
* Fri Aug 13 2021 Boris Manojlovic <boris@steki.net>
- updated to latest release 4.0.32
- New Features and Improvements
  + ZBXNEXT-6662 Increased field size to 2000 characters in web scenario variables
    and web scenario step variables and post fields
- Bug Fixes
  + ZBX-19558 Fixed creating of dependent item prototypes
  + ZBX-18695 Fixed file_put_contents() runtime error if web server has
    no write permissions for zabbix.conf.php
  + ZBX-19424 Fixed trigger handling failing if host name looks like a number
  + ZBX-19318 Added sorting by itemids for trends flush to avoid deadlock
  + ZBX-18879 Fixed update vmware info about vCenter fullname and version
  + ZBX-19447 Implemented item type validation by API
  + ZBX-19388 Fixed inherited graph and graph prototype update if user has
    no permissions to child host or template
  + ZBX-19358 Fixed memory leak in case of duplicate vmware hv uuid
  + ZBX-19248 Fixed retrieving of all data from separate database tables inside of
    API methods when empty value for filter is passed
  + ZBX-19300 Updated jquery version
  + ZBX-19139 Fixed memory errors in cmdline parsing on freebsd
  + ZBX-19359 Fixed error in logsource function due to empty source
  + ZBX-8999 Fixed exporting of images separately from other objects
* Thu Jun 24 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 4.0.31
  + ZBX-19334: removed redundant ListenIP parameter in server's
    configuration file
  + ZBX-19233: fixed potential loss of original error when reading
    vmware events
  + ZBX-18883: fixed logrt[] monitoring with copytruncate rotation
  + ZBX-19210: fixed css file versioning for custom themes
  + ZBX-18912: fixed escalation message is using template message
    instead of custom message in actions
  + ZBX-19195: fixed endless loop in graph widget processing if
    widget size is too small
* Wed Apr 14 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 4.0.30
- New features and improvements
  + ZBXNEXT-6528,ZBXNEXT-6565 Improved performance of host.create and
    template.create methods; improved performance of templates linking
    process; optimized DB::insert() method to send bulk SQL inserts
  + ZBX-19150 Added csrf check
  + ZBX-12867 reworked problem event popup of problems widget to load data
    only on mouse hover and click
  + ZBX-18998 Rewrote API main object validation
  + ZBX-19111 Improved performance of checking circular and double
    linkages of templates
  + ZBX-10370 allowed Java Gateway to use ssl with remote registry
  + ZBX-19149 updated logback-core, logback-classic and slf4j-api jars
    to the latest stable versions: 1.2.3, 1.2.3 and 1.7.30
- Bug fixes:
  + ZBX-19117 Fixed host deletion, template deletion and maintenance
    update was not shown in audit log report when it was made via
    API request
  + ZBX-17000 Changed translation of 'last' for week of month in
    japanese
  + ZBX-19023 Fixed inheritance of the permissions and tag filters
    for new host groups
* Wed Apr 14 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 4.0.29
- New features and improvements
  + ZBX-18886 Implemented proper resource cleanup when sender
    terminates by signal
  + ZBX-18449 Reworked trigger API validation
- Bugfixes
  + ZBX-18966 Fixed interface related errors when changing proxy
    type from passive to active
  + ZBX-18825 Fixed last year period calculation in service
    availability report daily mode
  + ZBX-18845 Fixed 'UserParameter' possible buffer overrun
  + ZBX-18887 Fixed user session expiration when notification checks
    are performed in background
  + ZBX-18309 Fixed reading log files with NULL character in log line
  + ZBX-18931 Fixed PHP runtime errors in CLineGraphDraw.php
  + ZBX-18872 Fixed system.sw.os[name] for cases without quotation
    mark in /etc/os-release
  + ZBX-18885 Fixed SNMP agent item not accepting values that are
    bigger than 2KB
  - Last update (4.0.28) also included a fix for CVE-2021-27927
* Thu Mar  4 2021 Boris Manojlovic <boris@steki.net>
- updated to latest release 4.0.28
- New Features and Improvements
  + ZBXNEXT-6364 Removed long lists of cloned objects from host and template full clone forms
  + ZBXNEXT-6307 Added ability to read properties from a file
- Bug Fixes
  + ZBX-18966 Fixed interface related errors when changing proxy type from passive to active
  + ZBX-18886 Implemented proper resource cleanup when sender terminates by signal
  + ZBX-18825 Fixed last year period calculation in service availability report daily mode
  + ZBX-18845 Fixed 'UserParameter' possible buffer overrun
  + ZBX-18449 Reworked trigger API validation
  + ZBX-18887 Fixed user session expiration when notification checks are performed in background
  + ZBX-18309 Fixed reading log files with NULL character in log line
  + ZBX-18931 Fixed PHP runtime errors in CLineGraphDraw.php
  + ZBX-18872 Fixed system.sw.os[name] for cases without quotation mark in /etc/os-release
  + ZBX-18885 Fixed SNMP agent item not accepting values that are bigger than 2KB
  + ZBX-18942 Fixed missing SID valiadion in authentication update route
  + ZBX-18893 Changed frontend config file permissions to 0600
  + ZBX-18884 Fixed crash in web monitoring and web.page.* keys
    when encoding non ASCII characters in URL
  + ZBX-18865 Fixed dbConditionInt (db.inc.php) returning wrong result in rare cases
  + ZBX-16216 Fixed semaphore not being cleaned up when stopping Zabbix agent
  + ZBX-18556 Fixed gaps in time labels of classic graphs related to DST transitions
  + ZBX-18644 Replaced deprecated gethostbyname function with getaddrinfo
  + ZBX-18802 Fixed close problem task to be deleted when problem event is deleted
  + ZBX-17865 Fixed displaying of long problem names on problems and event pages
  + ZBX-18796 Improved update performance of the preprocessing
    rules in item.update() and itemprototype.update() methods
  + ZBX-18623 Fixed the global search showing number of objects that user has no permissions
  + ZBX-18784 Fixed memory leak when handling vmware events
  + ZBX-18761 Fixed possible heap overflow issues in IPC commonications
    when deserializing huge text values
  + ZBX-18755 Fixed possibility of out of memory error when replacing string in mail,
    calculated checks, actions and when linking template
  + ZBX-18486 Fixed screen inheritance from a linked template in the full clone case
  + ZBX-18660 Fixed SNMP index returning as a number instead of string if there is a backslash
  + ZBX-17703 Fixed problem negative duration for timed triggers in case of database disconnect
  + ZBX-18694 Fixed crash when PSK connection is configured but PSK or PSK identity is empty
  + ZBX-18662 Improved pollers, unreachable pollers, Java pollers and pingers to use less memory
  + ZBX-18423 Fixed inconsistent macro expansion with Oracle DB compared with other databases
  + ZBX-18219 Fixed custom multiplier preprocessing step validation to accept a string with macros
  + ZBX-18422 Fixed "server is not running" warning message width
  + ZBX-18688 Fixed schema name didnt show when available only postgresql
* Fri Jan 15 2021 Boris Manojlovic <boris@steki.net>
- updated to latest release 4.0.27
- New Features and Improvements
  + ZBXNEXT-2480 Removed autocomplete from fields having sensitive data
- Bug Fixes
  + ZBX-18155 Removed positional macros from item names on 'Web monitoring' page
  + ZBX-5842 Fixed ability to detect username existence from unsuccessful login message
  + ZBX-18564 Moved taskid calculation to transaction when creating remote command task
  + ZBX-18487 Increased trapper verbosity for DebugLevel=4 when rejecting sender data
  + ZBX-18185 Fixed compilation error on Solaris 10
  + ZBX-18317 Fixed fatal error when updating only discovered triggers and their properties
  + ZBX-18163 Fixed deletion of one last remaining main host interface to show error
    instead of silently deleting the interface
  + ZBX-18058 Updated the list of item keys and their descriptions
  + ZBX-18464 Fixed javascript Uncaught TypeError when clicking on disabled multiselect item
  + ZBX-18411 Set maxQueryMetrics default values for vcenter depending on its version
  + ZBX-18438 Fixed missing asterisk mark for "timeout" field in item, item prototype and LLD rule edit forms
  + ZBX-18327 Fixed undefined index when invalid URL is given
  + ZBX-17178 Fixed multi-line value truncation in snmp lld
  + ZBX-18462 Fixed inconsistent auto-registration behaviour for hosts without metadata
    on Oracle DB compared to other databases when using Zabbix proxy
  + ZBX-18364 Fixed inconsistency with autoregistration behaviour for hosts without metadata
    on Oracle compared to other databases
  + ZBX-18365 Added Fping 5.0 support to Zabbix
  + ZBX-17493 Added discarding of incoming values outside history/trends storage periods on server
  + ZBX-18343 Fixed in screen "host issue" problem stay even after problem resolved
  + ZBX-17842 Updated VMware template to follow guidelines
  + ZBX-17848 Fixed fping interval detection, added log prints of detected
    options in debug mode, re-detect options every hour
  + ZBX-18188 Increased age and duration related macro resolution to seconds
  + ZBX-15651 Fixed handling of overlapping IP addresses in network discovery received from single Zabbix proxy
  + ZBX-18326 Fixed unsupported code for internet explorer
  + ZBX-15904 Added check of required cache size for vmware event messages
  + ZBX-18121 Fixed SSH monitoring when compiled with libssh; thanks to MATSUDA Daiki for the patch
  + ZBX-14503 Updated JMX template to follow guidelines
  + ZBX-18189 Fixed crash when performing housekeeping with disabled value cache
  + ZBX-18181 Fixed undefined index when importing host with non-existing interface
  + ZBX-18050 Removed proxy name from host breadcrumbs
  + ZBX-18202 Added new default item keys for item type "Zabbix aggregate"
  + ZBX-18124 Fixed discovered host group prototype saving during import
  + ZBX-13789 Fixed SQL errors with Oracle backend due to incorrect use of the USING statement
  + ZBX-18046 Improved error message generation performance of user macro and item key parser
  + ZBX-18105 Fixed use on uninitialised variable
  + ZBX-18014 Added ODBC empty query check
  + ZBX-18160 Fixed fatal error in items.php and host_discovery.php
  + ZBX-13383 Improved performance of the trigger and trigger prototype inheritance
  + ZBX-17974 Implement timeouts for WMI queries
  + ZBX-13789 Improved performance of "Problems" widget with MySQL backend by removing DISTINCT
    modifier from SQL statements with tables joined by primary keys
  + ZBX-17468 Fixed excess audit log record being added on host status update
  + ZBX-18076 Fixed PHP notice and multiple undefined index errors in hostinterface API
  + ZBX-18000 Added red label for disabled media types in user profile
  + ZBX-18075 Fixed runtime error when creating a host via API
  + ZBX-15927 Removed problem calculation for dependent triggers when master trigger is in problem state
  + ZBX-18063 Fixed usage of unsupported parameter in API call
  + ZBX-18060 Fixed inaccessible user be displayed as accessible in slide show properties screen
  + ZBX-17252 Fixed building of Zabbix daemons with link time optimization
* Thu Jul 30 2020 Boris Manojlovic <boris@steki.net>
- updated to latest release 4.0.23
- New Features and improvements
  + ZBXNEXT-6004 Added host info to vmware event message log
  + ZBXNEXT-5903 Added vmware datacenters discovery
- Bug Fixes
  + ZBX-8081 Fixed 'cmdline' parameter truncation on solaris 11.3 and later
  + ZBX-18014 Fixed memory leak when action message does not have to be sent
  + ZBX-15117 Fixed graph configuration with large amount of items
  + ZBX-18069 Fixed server exit when trying to execute ipmi script without ipmi pollers
  + ZBX-17960 Fixed undefined index in trends api
  + ZBX-17682 Fixed button disable state in template item list and discovery list
  + ZBX-17820 Fixed classic graph widget default header
  + ZBX-17924 Fixed php errors in "system information" window for mysql
  + ZBX-17917 Changed vm.memory.size keys on solaris to get memory usage statistics from kstat
  + ZBX-18029 Fixed cpu counter wraparound handling on solaris
  + ZBX-17624 Fixed misleading error message in case of not available datastorage
    for vmware.hv.datastore.read and vmware.hv.datastore.write metrics
  + ZBX-17860 Fixed host prototype import
  + ZBX-17922 Removed mtime check when matching files on disk with the cached list,
    this should reduce chances of log files being scanned again after system time changes
* Sat Jul 18 2020 Boris Manojlovic <boris@steki.net>
- updated to latest release 4.0.22
- Fixes CVE-2020-15803
- New Features and Improvements:
  + ZBXNEXT-3588 Improved Zabbix server performance when evaluating
    trigger, discovery, autoregistration and internal actions
  + ZBXNEXT-5922 Increased max configuration cache size limit to 64GB
  + ZBXNEXT-4829 Changed web setup wizard to not create
    and drop tables for DB connectivity test purposes
- Bug Fixes:
  + ZBX-17720 Exclude disabled items from preprocessing configuration sync
  + ZBX-17851 Fixed possible deadlocks when deleting escalations
  + ZBX-17406 Fixed null value for a field of compositedata in jmx discovery
  + ZBX-17891 Changed log, log.count monitoring to ignore file modification time
  + ZBX-17697 Fixed strict dfsg compliance issue in using minified jquery sources
  + ZBX-16461 Fixed recovery expression for "link down" trigger and updated
    for following zabbix template guidelines
  + ZBX-17702 Fixed escalation cancellation message not being sent when action is disabled
  + ZBX-17480 Fixed context of {$temp_crit} macro in temperature trigger prototype
  + ZBX-17694 Fixed high memory consumption when using dependent items
  + ZBX-17780 Fixed memory leak
  + ZBX-17577 Fixed remove of selected items in multiselect
  + ZBX-17226 Fixed confusing error message being displayed if dbversion table cannot be found
  + ZBX-17801 Shadow global auto_increment mysql variables only for proxy
  + ZBX-17662 Fixed a failing query when updating existing host prototypes
  + ZBX-15484 Shadow global auto_increment variables for mysql
  + ZBX-17607 Fixed unreachable poller being too busy due
    to snmp checks being attempted twice at a time
  + ZBX-17629 Fixed markup in user media popup
  + ZBX-17109 Fixed agent request parameter type parsing
  + ZBX-17470 Fixed element of filters is not focused on several pages
  + ZBX-17691 Fixed server crashes on regexp preprocessing
  + ZBX-17445 Fixed misleading error shown when formula cannot be updated during lld
  + ZBX-17186 Fixed context-aware lld macro expansion in jsonpath preprocessing
  + ZBX-17524 Fixed time selector button state
  + ZBX-17496 Fixed usermacro api validation
  + ZBX-17532 Added css files and sprites versioning by query strings
  + ZBX-17501 Fixed overlapping multiselect suggest with browser autocomplete
  + ZBX-17402 Fixed search field accidentally transform value to lowercase
  + ZBX-17505 Fixed crash inside a fork when calling vfs.fs.inode
  + ZBX-16959 Fixed return code check of curl_easy_setopt
  + ZBX-17423 Fixed "reset" button in history page
  + ZBX-17395 Fixed deletion of templated applications that were
    linked to items when importing templates
  + ZBX-17359 Fixed "sortorder": "desc" option with multiple sortfields
  + ZBX-17336 Fixed wrong error message when fping fails
  + ZBX-17427 Fixed top busiest triggers filter
  + ZBX-17523 Fixed agent compilation on windows
  + ZBX-17508 Fixed error in oracle database encoding check
  + ZBX-17442 Fixed web.page.get to time out when there is no response
  + ZBX-17429 Fixed trigger expression condition popup to display
    negative numbers upon opening existing expression
  + ZBX-17012 Fixed url validator to also accept relative urls
  + ZBX-17507 Fixed oracle query interpreted as a multistatement
  + ZBX-9387 Fixed incorrect maintenance calculations when dst changed to summer time
  + ZBX-17390 Fixed validation of the maximum selected period
* Thu Apr 23 2020 Boris Manojlovic <boris@steki.net>
- updated to latest release 4.0.19
- replaced URL for source downloads to zabbix CDN network location
- New Features and improvements
  + ZBXNEXT-5649 Added name referencing support ('~' suffix) to jsonpath
  + ZBXNEXT-3604 Added support of user configurable ciphers for communication between zabbix components
- Bug Fixes
  + ZBX-17173 Improved windows agent build scripts
  + ZBX-17425 Fixed template.massupdate api macros update
  + ZBX-17344 Fixed php 7.4 errors in latest data->history page for text and
    log items having an empty filter
  + ZBX-17330 Fixed error reading vmware events with keys over 2^31
  + ZBX-17288 Fixed undefined indexes in administration->regular expressions->test tab
  + ZBX-17350 Fixed displaying of multiple value types in latest data->history page
  + ZBX-16802 Added mtime-reread/mtime-noreread options parameter to log* keys
  + ZBX-17390 Fixed validation of the maximum selected period
  + ZBX-17185 Fixed non-disappearing messages of failed login attempts
  + ZBX-17322 Fixed deadlock between server and frontend when updating multiple hosts
  + ZBX-9057 Fixed duplicate entries being written into in profiles table
  + ZBX-17159 Fixed overlay dialogue instantiation
  + ZBX-17108 Improved process utilization calculation
  + ZBX-17269 Fixed undefined indexes in history page
  + ZBX-17342 Dump memory statistics and items with most values when value cache is fully used
  + ZBX-16926 Fix int_max error when compiling on sunos/joyent/solaris
* Mon Dec 23 2019 Boris Manojlovic <boris@steki.net>
- updated to latest release 4.0.16
- New Features and Improvements
  + ZBXNEXT-5271 Implemented 'delete missing' option for imported template linkages
- Bug Fixes
  + ZBX-17101 Fixed url validation before output
  + ZBX-16929 Fixed detection of invalid sender data request
  + ZBX-16804 Added missing get parameters in availability report
  + ZBX-16286 Fixed graph widget dimensions errors on high dpi screens
  + ZBX-16848 Fixed fatal error occurring in user profile and user edit
    forms when php fileinfo extension does not exist
  + ZBX-16684 Fixed incorrect double quotes in history plain text view
  + ZBX-16903 Fixed validation of "interfaceid" field for http agent items with large ids
  + ZBX-16751 Fixed support for php 7.4
  + ZBX-16879 Changed condition description message for tag value in actions and event correlations
  + ZBX-9084 Fixed high memory usage during startup
  + ZBX-16932 Fixed build fail on netbsd
  + ZBX-16111 Removed templateid from screen api output
  + ZBX-16919 Fixed server check warning width in chrome
  + ZBX-16944 Fixed "type of information" field in item form being marked as required when it is read-only
  + ZBX-16912 Fixed image map elements having a hand cursor when there is no context menu available
  + ZBX-15041 Fixed request not being cancelled along with popup window in widgets
  + ZBX-1977 Fixed axis labels calculation
  + ZBX-17034 Updated zabbix website links
  + ZBX-16874 Fixed map-type widget clipping in internet explorer
  + ZBX-16915 Fixed memory leak
  + ZBX-17008 Improved zabbix server performance when using maintenance
  + ZBX-16779 Fixed infinite loop when writing export to file fails
  + ZBX-16540 Splitted host_resources templates into 3 subtemplates: for cpu, memory and storage
* Thu Nov 28 2019 Boris Manojlovic <boris@steki.net>
- updated to latest release 4.0.15
- New Features and Improvements
  + ZBXNEXT-5493, ZBX-16540 Moved lld rules from parent templates to linked templates for module
    host-resources-mib snmpv2, module interfaces windows snmpv2, net arista snmpv2, os windows snmpv2
  + ZBX-16871 Fixed not setting the default values of multiselects on initial load
  + ZBX-16776 Reworked custom item select to multiselect
  + ZBXNEXT-5532 Disabled guest user by default
  + ZBXNEXT-4825 Implemented in monitoring -> problems the button "export to csv" to export all pages
- Bug Fixes
  + ZBX-16955 Fixed performance of history syncers and timer processes by not locking
    each other when suppressing events
  + ZBX-16842 Added range validation and optional conversion to is_double()
  + ZBX-16790 Fixed log rotation on windows
  + ZBX-16865 Fixed dynamic graphs not updating when changing host in combo box
  + ZBX-9146 Fixed json null value being treated as empty string for lld filters
  + ZBX-16828 Fixed array_db validation when validated value is not an array
  + ZBX-11659 Made user profile icon visible for guest user
  + ZBX-16849 Moved interface_type_priority definition to misc.c
  + ZBX-16844 Fixed the process of saving the scroll position on the latest data page in internet explorer
  + ZBX-16343 Fixed lld not to create items on wrong host if there are failed transactions
  + ZBX-16730 Fixed disappearance of successful modification message while saving the dashboards
  + ZBX-16679 Fixed username and password fields resetting and saving for
    item, item prototype and lld rule on type change
  + ZBX-16785 Improved performance of timer process when reading from "problem_tag" table
  + ZBX-16696 Fixed multiselect suggest box clipping when overflowing not allowed in parent containers
  + ZBX-16809 Fixed undefined offset error in action operation condition form
  + ZBX-16595 Optimized active logs checks monitoring when buffer flushing fails
  + ZBX-16682 Fixed wrong element label update in map constructor
  + ZBX-16815 Fixed widget form positioing when changing widget type from graph to any other type
  + ZBX-16706 Fixed unneeded padding for dashboard url widget
  + ZBX-16784 Fixed oracle performance by using "between" operator in sql queries
  + ZBX-16579 Fixed long text wrapping in the latest data history
  + ZBX-16767 Fixed possible null pointer arithmetic; thanks to mikhail grigorev for the patch
  + ZBX-16500 Fixed sla calculation when requested time window starts during
    the service time; fixed downtime time calculation
  + ZBX-16805 Fixed when the httptest api selects too many entries from the httpstep
    table when editing a specific web scenario
  + ZBX-10618 Fixed disappearing dependent trigger cells and rows in overview
  + ZBX-16596 Added handling of bom to detect encoding for vfs.file.contents, vfs.file.regex and vfs.file.regmatch
  + ZBX-16771 Fixed wrong tab number being remembered when several browser tabs are in use
  + ZBX-16548 Fixed sort order in plain text screen
* Wed Oct 30 2019 Boris Manojlovic <boris@steki.net>
- updated to latest release 4.0.14
- New Features and Improvements
  + ZBXNEXT-5481 Added support of {trigger.id} macro in trigger tags
  + ZBXNEXT-4746 Added "template server cisco ucs snmpv2" template
  + ZBXNEXT-5422 Quoted numbers are now accepted by jsonpath aggregate functions
- Bug Fixes
  + ZBX-16605 Fixed accessibility of localstorage identifier if cookies are
    made unaccessible for client side scripts
  + ZBX-16754 Fixed trigger not firing for first collected value if it's timestamp is in future
  + ZBX-15211 Added key 'tests' for bootstrap.sh when working with cmocka tests
  + ZBX-16542 Fixed incorrect displaying of unacknowledged and resolved
    recent problematic triggers in trigger overview and dashboard widget
  + ZBX-16749 Improved performance and memory consumption of script.getscriptsbyhosts() method
  + ZBX-16725 Fixed detection of fping minimal interval
  + ZBX-16562 Fixed configuration.export method in api improperly formatting
    "application" property within "httptests" when exporting in json format
  + ZBX-15222 Fixed housekeeper to cleanup history not only for current item
    type of information but also for other previously selected types
  + ZBX-16481 Fixed spelling issues in the code
  + ZBX-15675 Added support for more than 64 cpus in windows agent
  + ZBX-16770 Fixed value mapping in template net hp comware hh3c snmp
  + ZBX-16534 Fixed stdout and stderr redirection after external log rotation
  + ZBX-16368 Fixed fping double call
  + ZBX-16317 Fixed log.h is not self-sufficient
  + ZBX-16711 Ensuring errbuf is emptied before every curl_easy_perform request
  + ZBX-16664 Fixed ipmi poller skips processing if one of the elements is missing information
  + ZBX-16671 Fixed server crashing when linking web scenario template
  + ZBX-16750 Fixed broken validation of peer certificate issuer
    and subject strings in tls connect, fixed logging
  + ZBX-16002 Added new macro event.recovery.name to display
    recovery event name in recovery alerts
  + ZBX-16512 Fixed false item insertion into the queue after maintenance
  + ZBX-15685 Fixed zabbix_sender failing to report the error due to closed connection
  + ZBX-16702 Fixed error in the elastic search clearing history
  + ZBX-10805 Fixed log items graphs drawing with numeric values like trapper items
  + ZBX-16604 Fixed occurrence of an undefined index in discovered graph configuration
  + ZBX-16611 Fixed memory and performance leaks in gtlc.js library
  + ZBX-15135 Fixed incorrect triggers being displayed in
    availability report when filtering by template
  + ZBX-16681 Fixed displaying of "acknowledge" menu option
    for "not classified" problems in the trigger overview page
  + ZBX-16428 Fixed sigbus crash when mmap memory is not accessible
  + ZBX-16680 Fixed freeing locked resources when zabbix agent
    cannot be started and has to exit with failure
  + ZBX-16666 Fixed trailing slash being set in cookie path
  + ZBX-16612 Fixed possibility of high cpu usage on windows
  + ZBX-16683 Fixed race condition between history syncer
    and escalator that caused recovery operations being delayed by step duration
  + ZBX-16383 Adjusted timer sleeping period to process maintenances each minute at 00 seconds
  + ZBX-16575 Getting disk controller type from linked controller label value
  + ZBX-16561 Fixed jsonpath parsing for comma characters inside quoted string
  + ZBX-16677 Fixed empty sql query dbexecute_overflowed_sql call during host availability update
  + ZBX-15897 Fixed overall health check in template hp ilo snmpv2
* Thu Aug 29 2019 Boris Manojlovic <boris@steki.net>
- updated to latest release 4.0.11
- New Features and Improvements
  + ZBX-9522 Improved frontend messaging usage across multiple browser tabs
- Bug Fixes
  + ZBX-16501 Fixed log out form being resubmitted when user is already logged
    back in another tab
  + ZBX-16072 Added more strict validation of host, template and proxy names
    to prohibit leading and trailing spaces
  + ZBX-16128 Fixed incorrect action id in audit log
  + ZBX-16354 Fixed incorrect sorting by name with capital letters
  + ZBX-16346 Fixed compilation for oracle instant client v18.5 and higher
  + ZBX-16424 Fixed unable to create/update web scenario from internet explorer/edge
  + ZBX-16471 For consistency reason changed translation string 'resolved by user.'
    to 'resolved by inaccessible user.'
  + ZBX-16469 Fixed problem that caused impossibility to edit trigger
    description in problems screen
  + ZBX-16362 Fixed keyboard event handling in graph widget hintbox
  + ZBX-16474 Fixed 'request-uri too long' error in problems mass update page
  + ZBX-16184 Updated zabbix sender man page
  + ZBX-16462 Fixed syntax error in sql query used to calculate sla in monitoring->services
  + ZBX-16031 Reworked event update controller, making partly closed set of events closable
  + ZBX-16283 Fixed read-only shared dashboard without widgets missing placeholder label
  + ZBX-16316 Fixed dashboard widget and slideshow menu popup not
    updating current refresh rate and fixed a js error in slideshows
  + ZBX-16346 Fixed compilation for oracle instant client v18.5 and higher
  + ZBX-16424 Fixed unable to create/update web scenario from internet explorer/edge
* Mon Aug 26 2019 Marketa Calabkova <mcalabkova@suse.com>
- restructured for easier maintenance because of bsc#1144018 and FATE#324346
  * many thanks to Boris Manojlovic, Kristyna Streitova, Matthias Gerstner
    and Tomas Chvatal for their help
  * skipped renaming of binaries
  * updated Apache config file
  * added logrotate to rotate logs
  * and other changes
- added README-SSL.SUSE to tell users how to configure SSL
* Wed Aug 14 2019 Boris Manojlovic <boris@steki.net>
- updated to latest release 4.0.11
- New Features and Improvements
  - ZBXNEXT-4502,ZBXNEXT-5176 	Added support of full jsonpath functionality
  - ZBXNEXT-5205 Blocked zero item history/trends
    period being overridden by global configuration
- Bug Fixes
  + ZBX-16376 Fixed preprocessing steps having incorrect order
    and duplicate step numbers
  + ZBX-16344 Fixed possibility to add graph widget overrides
  + ZBX-16388 Fixed lld to update preprocessing step number
    in case it is incorrectly generated
  + ZBX-16337 Fixed debug log message for suppressed escalations;
  thanks to kotaro miyashita for the patch
  + ZBX-16287 Fixed compiler warnings in host.c; thanks to
    glebs ivanovskis for the patch
  + ZBX-16103 Reduced pcre recursion limit
  + ZBX-16289 Fixed async dashboard widget update
  + ZBX-13266 Improved performance of the sql queries
    with lot of ids in the condition
  + ZBX-16277 Fixed compilation zabbix agent for windows with
  options available for windows vista and newer
  + ZBX-16239 Fixed compilation warining related to prototypes
    of module api functions
  + ZBX-16256 Eliminated possible infinite fetch loop with oracledb
  + ZBX-15343 Fixed js memory leak in hintboxes in graph widget
  + ZBX-16329 Fixed duplicate value checking in trigger action conditions
  + ZBX-15562 Reworked history.get api method; fixed output
    as well as other known issues in history api
  + ZBX-16135 Fixed error messages in xml export files
  + ZBX-16213 Fixed postgresql bad performance on history tables
  + ZBX-16176 Preserve trailing spaces in history values
  + ZBX-16169 Improved performance of map navigation tree widget
  + ZBX-16288 Fixed when unknown resource logged in
    audit log when working with dashboards
  + ZBX-16134 Fixed duplicate triggers can be created
  using api and xml import
  + ZBX-15969 Fixed displaying of very small values that
    are more than 2 decimal points in latest data
  + ZBX-16280 Fixed when plain text widgets do not display
    as html when option is selected
  + ZBX-16012 Fixed confusing error message "cannot read json." in http agent item
  + ZBX-16270 Fixed memory leak in ipc service when queueing multiple messages to client
  + ZBX-16204 Fixed undefined offset in ccontrollerwidgetproblemhostsview
  + ZBX-15962 Added mounted filesystems to vfs.fs.discovery of windows agent
  + ZBX-16315 Fixed zabbix server not to cause foreign key constraint failure
    on zabbix proxy when changing and sending configuration at the same time
  + ZBX-16153 Fixed 500 internal server error when trying to preview pie/exploded graph without items
  + ZBX-9867 Improved zabbix daemon termination by not using signal
    unsafe functions in signal handler; improved zabbix server and zabbix proxy
    process termination by stopping data collection and waiting for history syncers to finish
* Mon Jul  1 2019 Boris Manojlovic <boris@steki.net>
- updated to latest release 4.0.10
- New Features and Improvements
  + ZBXNEXT-2880 Added access to vmware datastore at vmware vcenter level
  + ZBXNEXT-5163 Added display of maintenance information in configuration
    section for hosts in maitenance
  + ZBXNEXT-5036 Added preloader for popup menus
  + ZBXNEXT-287 Added ssl support for agent http checks
  + ZBXNEXT-5179 Added option to specify absolute path in loadmodule;
    thanks to glebs ivanovskis for the patch
- Bug Fixes
  + ZBX-16315 Fixed zabbix server not to cause foreign key constraint failure
    on zabbix proxy when changing and sending configuration at the same time
  + ZBX-9867 Improved zabbix daemon termination by not using signal unsafe
    functions in signal handler; improved zabbix server and zabbix proxy process
    termination by stopping data collection and waiting for history syncers to finish
  + ZBX-16152 Fixed not data loss on saving host prototypes by user with insufficient permissions
  + ZBX-15952 Fixed errors when trying to create a graph widget for key
    system.cpu.util[,iowait] with y axis placed on the left side of the graph
  + ZBX-15899 Added output sanitization to prevent invalid utf-8 sequences
    in regexp-based text replacement
  + ZBX-16073 Fixed horizontal scrolling in map
  + ZBX-15943 Fixed discovered hosts are not removed from table "dhosts" after
    removing and adding the corresponding discovery check
  + ZBX-15875 Fixed colors for the multiselect disabled elements
  + ZBX-10948 'it services --> service time --> note' infinite stretching
  + ZBX-16142 Fixed missing sys/ioctl.h from src/libs/zbxsysinfo/openbsd/net.c;
    thanks to andrea biscuola for the patch
  + ZBX-16166 Fixed zabbix fping feature detection does not work with fping builds since 10 feb 2017
  + ZBX-16178 Fixed distributive can contain untracked backup file include/config.h.in~
  + ZBX-16170 Fixed crash in global event correlation
  + ZBX-16096 Fixed "system.cpu.util" reporting incorrect cpu utilisation due to guest time
    sometimes not being fully included in user time by "/proc/stat"
  + ZBX-15882 Fixed widgets flickering on refresh
  + ZBX-15974 Improved trigger expression list in trigger modal form
  + ZBX-14441 Fixed windows agent "eventlog" key for reading big event log files of windows 2003
  + ZBX-16109 Fixed hidden error in graphs for php 7.3.5
  + ZBX-16093 Fixed regular expression file systems for discovery does not contain apfs
  + ZBX-16080 Fixed setup page to not to use bclib
  + ZBX-15797 Fixed dashboard map widget sub-map link behaviour
  + ZBX-15049 Fixed to host group limited global scripts to be usable in sub group
  + ZBX-16138 Fixed return value type and added preprocessing steps for items in remote
    internal checks tamplates; fixed unsigned write cache value for remote internal checks
  + ZBX-15963 Fixed http agent support of non-http scheme in url field
  + ZBX-16151 Fixed theoretical possibility of large numbers in json data being truncated,
    added boolean value support to json parser
  + ZBX-15778 Fixed wrong filtering by "age less than" and "show suppressed problems" in trigger overview
  + ZBX-15585 Fixed web scenarios pair manager issue when fields are duplicating on post type toggle
  + ZBX-16150 Fixed inactive, unmounted, unaccessible vmware datastore causes
    unknown column nan insertion in field list
  + ZBX-16122 Fixed api validation of trigger dependency
* Tue Jun 11 2019 Boris Manojlovic <boris@steki.net>
- updated to latest release 4.0.9
- Bug Fixes
  + ZBX-15905 Reverted changes that introduced error with
    write permissions in assets directory
* Fri May 31 2019 Boris Manojlovic <boris@steki.net>
- updated to latest release 4.0.8
- New Features and Improvements
  + ZBX-16069 Upgraded jquery version v1.10.2 -> v3.3.1
    and jqueryui v1.10.3 -> v1.12.1
- Bug Fixes
  + ZBX-16032 Changed application filtering to partial name search
  + ZBX-15915 Fixed linking error if round() is undefined
  + ZBX-16074 Added file revision number generation for
    compilation on ms windows
  + ZBX-15833 Fixed scrollbar in overlay popups
  + ZBX-16058 Fixed error in ipmi poller causing growing queue
  + ZBX-16047 Fixed division by zero error in svg graph widget if selected
    time period is so small that calculated step between 2 milestones is 0s
  + ZBX-15936 Removed "change password" button when cloning media types
  + ZBX-11272 Changed sorting by type, fixed information disclosure and
    formatting of recipient name in action log screen item and dashboard widget;
    added new sortfields to alert api
  + ZBX-15416 Fixed locale validation in user create and update api methods
  + ZBX-15877 Fixed tab key navigation for safari and edge browsers
  + ZBX-15891 Fixed trigger dependencies are ignored when changing only trigger state
  + ZBX-13029 Fixed api validation messages for linktrigger
  + ZBX-15967 Fixed buffer offset for reading hardware info from long dmi files
  + ZBX-16018 Fixed detection of logical functions (or / and) inside
    the context of user macros
  + ZBX-14782 Deliver human friendly uptime in dashbord
  + ZBX-11325 Fixed transparency of draggable interfaces; changed cursor
    type for all draggable and sortable elements
  + ZBX-16048 Fixed global search box loosing the search phrase after searching
  + ZBX-10729 Fixed map element link coloring when linked problem is acknowledged
  + ZBX-15101 Fixed several object ids allowing them to be 64 bit integers,
    added asterisk for map navigation tree name field and changed
    the error message to more generic one
  + ZBX-16050 Fixed http poller crashes
  + ZBX-15871 Fixed problem events to be filtered by "suppressed"
    instead of "related to maintenance"
  + ZBX-10550 Added warnings when zabbix components have different versions
  + ZBX-11284 Removed sid url argument for form cancel buttons
  + ZBX-11429 Fixed macro not being retained in trigger expression editing wizard
  + ZBX-15816 Increased header value input field max length
  + ZBX-15677 Fixed the process of compiling the dummy.c module
  + ZBX-15981 Fixed invalid xpath for vmware "eventlog" key with "skip" option
  + ZBX-15704 Fixed sending log meta information without obvious needs
  + ZBX-15905 Added versioning of browser cached files
  + ZBX-15956 Reduced configuration cache fragmentation
    when reloading time based triggers
  + ZBX-15998 Improved performance of "remove host", "remove from host group",
    "unlink from template" operations when processing network
    discovery events and using mysql database
  + ZBX-15935 Fixed infinite loop and 100%% cpu usage
    when using openipmi 2.0.26 or newer
  + ZBX-16005 Fixed "{{item.value}.regsub(<pattern>,<output>}" and
  "{{item.lastvalue}.regsub(<pattern>,<output>}" being resolved to *unknown* during upgrade
* Wed Apr 24 2019 Boris Manojlovic <boris@steki.net>
- updated to latest release 4.0.7
- Bug Fixes;
  + ZBX-16019 Fixed host.conn, host.ip, ipaddress and host.dns
    macros expansion in global scripts
  + ZBX-16020 Fixed uncontrolled memory allocation in regex preprocessing steps
  + ZBX-15911 Fixed guest sign in visibility for disabled guest
    user group in login page
  + ZBX-15977 Fixed validation of host interface when multiple
    interfaces set as main interface
  + ZBX-15955 Fixed security vulnerability - accepting connections
    from not allowed addresses
  + ZBX-11393 Fixed when long snmp oid expands screen dimensions
  + ZBX-15464 Fixed error message for image uploads
  + ZBX-10243 Fixed not encoded ampersand for in url parameter
  + ZBX-15972 Fixed possible crash of the windows agent when
    used "net.dns" item key
  + ZBX-15674 Fixed map status to be displayed ok if there
    are no problem in submaps
  + ZBX-15970 Fixed invalid update intervals being reported
    on zabbix server when monitored through zabbix proxy
  + ZBX-15643 Fixed invalid to valid numbers conversion by del_zeros
  + ZBX-15444 Fixed trimming allowed characters from numeric values
  + ZBX-15409 Improved zabbix java gateway error logging
    usability by adding item key to error message
  + ZBX-15844 Fixed inability to start zabbix server if alert manager
    process is late after alerters; thanks to mikhail makurov for the patch
  + ZBX-11043 Implemented a better network discovery filter
  + ZBX-10937 Fixed top right global search field autocomplete not showing
    results when host name is being typed not first character and technical
    name when it differs from visible name
  + ZBX-10861 Changed user name and password fields from being mandatory to
    optional in web scenarios and http agent type items
  + ZBX-10889 Improved logging performance when high debuglevel is used
  + ZBX-15762 Fixed api returns "countoutput", "select*": "count" results and
    "suppressed" property as integer
  + ZBX-15642 Fixed bigint limit in the user group updating forms
  + ZBX-2494 Fixed sorting of items, item prototypes, lld rules and screens
    to avoid deadlocks in database between server and frontend
  + ZBX-15768 Fixed line length above widgets on global search page
  + ZBX-10404 Fixed password being passed in plain text in media type edit form
  + ZBX-15734 Fixed dashboard widgets incorrect placement while dragged
  + ZBX-15563 Fixed svg graph metric generation in situation when metric have big values
  + ZBX-15139 Fixed element removing from list in different tabs or browsers
  + ZBX-15779 Fixed loss of host name in tooltip on trigger overview page
  + ZBX-15898 Fixed compilation warning regarding too large integer constant
  + ZBX-15338 Fixed last problem name being displayed on map instead of most critical
  + ZBX-15929 Fixed escalation operation not being send multiple times
  + ZBX-15721 Fixed escaping of control characters in json encoder
  + ZBX-15507 Fixed item/trigger/graph copy form provides read-only host groups
    in target list; replaced form elements with multiselect
  + ZBX-15746 Fixed link to pie graph after selecting a time interval on classic graph
  + ZBX-15784 Fixed multiselect does not support case sensitive auto-complete
  + ZBX-10799 Changed placeholder for http proxy input fields
  + ZBX-13014 Fixed map on screen is not centered
  + ZBX-9229 Fixed sending first value of the log as separate message
  + ZBX-15479 Fixed cookie presentation in http header
  + ZBX-15516 Fixed trapper process title to not update time in case of interruption
  + ZBX-15588 Fixed function names that are written to the log file when
    using log_level_debug
  + ZBX-9150 Fixed update intervals of items in vmware templates
  + ZBX-15481 Fixed showing wrench icon for hosts that are in maintenance,
    but maintenance is inaccessible due to insufficient permissions
  + ZBX-15629 Fixed trigger wizard form re-submit
  + ZBX-15850 Fixed problems by severity filter ignoring host group filter
  + ZBX-15853 Fixed empty parent group not listed in the latest data filter
  + ZBX-11025 Added "unknown command error" to mysql recoverable error list
  + ZBX-15870 Fixed redundant jsloader loading in login page
  + ZBX-15858 Fixed item filtering by application name; added 'select' button
    for dashboard widget and screen item application fields
  + ZBX-15851 Fixed lld item displaying in queue details view
  + ZBX-15639 Fixed labels overlapping on classic graph x axis
  + ZBX-15592 Fixed database monitoring 'dns' item key expressing it as mandatory
  + ZBX-15859 Fixed map.create could attach elements only for first map
    in request when multiple maps are created with one request
  + ZBX-15769 Fixed new widget placeholder being shown outside maximum
    allowed dashboard height area
  + ZBX-15708 Fixed browser build in autofill for passwords field on media
    type form on authentication ldap form and on user edit form
  + ZBX-10392 Fixed application filter persistence when navigating from
    maps page to triggers views page or latest data page
  + ZBX-15754 Removed unnecessary request for non-existing map background
  + ZBX-15715 Added missing keys "zabbix.stats[<ip>,<port>]", "zabbix.stats[<ip>,<port>,queue,<from>,<to>]"
    and "zabbix[stats,<ip>,<port>,queue,<from>,<to>]" in item key helper
  + ZBX-15672 Fixed positioning of the overlay dialogue window in map constructor
  + ZBX-15609 Added missing optional parameter "<regex_excl_dir>" for "vfs.dir.count"
    and "vfs.dir.size" item keys in item helper
  + ZBX-15404 Fixed action condition type and operator integrity
  + ZBX-15913 Fixed possible crash when sending custom alerts
  + ZBX-15872 Fixed possible deadlock on host table when processing auto
    registration contents from zabbix proxy
  + ZBX-11203 Added blocking of sigint and sigterm signals on each step of
    automatic upgrade to avoid interruption of statements that cannot be rolled back
  + ZBX-8451 Fixed global regular expression testing not matching actual
    behavior of zabbix components due to missing multiline flag
  + ZBX-13347 Fixed possible crash in history syncer process when processing discovered item value
  + ZBX-15831 Fixed slow request of vmware configuration update
  + ZBX-15920 Fixed nodata() function triggering after maintenances with
    no data collection without waiting for the nodata period
  + ZBX-13478 Fixed item prototype update intervals to eliminate trigger status flapping
  + ZBX-10611 Fixed changing process user owner on startup
    in foreground when allowroot disabled
  + ZBX-15826 Optimized unsupported macros parsing
  + ZBX-15742 Fixed network discovery is not reacting to the changes
    in agent configuration if uniqueness criteria is value
  + ZBX-15634 Fixed database monitor item does not use stored credentials;
    thanks to jose deniz for the patch
* Mon Apr  1 2019 Boris Manojlovic <boris@steki.net>
- updated to latest release 4.0.6
- New Features and Improvements
  + ZBXNEXT-5105 added context menu for trigger name in event details page
  + ZBX-15286 dropped support use of discovered items as master
  + ZBXNEXT-4898 added support IPv6 for "net.dns" and "net.dns.record"
  + ZBXNEXT-5037 added "skip" parameter for vmware.eventlog key
  + ZBXNEXT-4819 implemented date and time showing in SVG graph widget
- Bug Fixes
  + ZBX-15839 fixed broken layout of the breadcrumbs in Safari browser
  + ZBX-15867 fixed invalid DNS being accepted when receiving discovery
    contents from Zabbix proxy
  + ZBX-15821 fixed SQL statement performance used in template.unlink() method
  + ZBX-15578 fixed IPMI errors in case of infrequent reading of values
  + ZBX-15098 fixed undefined index in application selection popup window
  + ZBX-15351 fixed PHP error in "Problems by severity" if no problems
  + ZBX-15552 fixed compilation with LibreSSL as OpenSSL replacement
    and OpenSSL without PSK support
  + ZBX-10317 made info column on item list page always visible
  + ZBX-15322 fixed graph area near grid line with 0 value
  + ZBX-15798 fixed proxy configuration update failure on Oracle;
    fixed failure on empty SQL buffer on Oracle
  + ZBX-15219 fixed unwanted removing scenario post fields on scenario update
  + ZBX-11278 reworked property state indicator in mass update screens
  + ZBX-15716 fixed escalation cancel message is called if escalation
    interrupts with unfinished step or recovery
  + ZBX-15468 fixed LDAP configuration form not being able to save changes
    when user password field is empty string
  + ZBX-15669 fixed page scroll after widget being added to dashboard
  + ZBX-15548 fixed resolving of {ITEM.VALUE} macro in the trigger description
  + ZBX-15774 fixed memory leak in housekeeper when elasticsearch is used
  + ZBX-15788 fixed crash when substituting LLD macros in calculated
    item formula expression
  + ZBX-15608 fixed when Widget Graph show disabled trigger/problem
  + ZBX-10397 fixed when global messaging severities unchecked if profile
    saved earlier
  + ZBX-15596 fixed when widget in frontend can be created larger
    than API validation supports
  + ZBX-15308 fixed timeselector in screens when page is opened
    with link containing sid argument
  + ZBX-15694 fixed trimming of empty spaces for custom multiplier
    in item and item prototype preprocessing forms
  + ZBX-15196 fixed "Follow redirects" checkbox not being enabled by
    default for HTTP agent in item, item prototype and LLD rule create forms
  + ZBX-15670 fixed inefficient vmware eventlog downloading
  + ZBX-15483 fixed undefined index in Item Prototype update
  + ZBX-15270 fixed graph widget configuration form cross browser issues
  + ZBX-15300 fixed widgets extra space at the bottom
  + ZBX-8091 added alphabetic ordering of net.dns.record respond
  + ZBX-15707 fixed check box design when drag and drop an interface into SNMP
  + ZBX-15535 fixed validation of min/max value range in graph widget;
    fixed translation string in graph widget
  + ZBX-15648 removed unused WIDGET_HAT_EVENTACTIONMCMDS
    and WIDGET_HAT_EVENTACTIONMSGS constants
  + ZBX-15386 fixed Trigger overview not showing OK triggers
  + ZBX-14538 fixed error message when value of lifetime
    or history/trends storage period is out of range
  + ZBX-15614 fixed validation of y axis item on classic graph create and update
  + ZBX-15226 fixed missing visual gap under page title
  + ZBX-15560 fixed incorrect URL argument formatting when parameters
    are non-indexed arrays
  + ZBX-15719 fixed undefined index in trigger expression popup
  + ZBX-15332 fixed dashboard svg graph update on timeselector interval change
  + ZBX-15728 fixed agent startup problem in Win 2008 R2 w/o SP1,
    removed dependency on version helper API
  + ZBX-15622 fixed trigger expression test dialog not being usable
    with long trigger expressions
  + ZBX-13332 fixed Request-URI Too Long errors in PopUps;
    fixed lost focus, when closing error popup
  + ZBX-15607 fixed possibility of zombie processes occurring
    when signaling agent during metric execution
  + ZBX-10496 fixed links to installation instructions in README file
  + ZBX-15625 removed links leading to media type edit form for
    non-superadmins in Reports->Notifications page
  + ZBX-15703 fixed use of uninitialized variable when receiving 0 bytes on listening socket
  + ZBX-15537 fixed visual bug when filter tab was overlapped by sub navigation
  + ZBX-15539 fixed validation of master item in item update form
  + ZBX-15532 fixed undefined index error on problems page when trigger expression contains web items
  + ZBX-15488 fixed permission check for inherited triggers
  + ZBX-15646 fixed web-server 'Request-URI Too Long' error in trigger description dialog
* Mon Feb 25 2019 Boris Manojlovic <boris@steki.net>
- updated to latest release 4.0.5
- New Features and Improvements
  + ZBXNEXT-5046 added non-destructive resizing and reordering of dashboard widgets
  + ZBXNEXT-401, ZBXNEXT-4907, ZBXNEXT-4955 added monitoring of internal
    metrics from an external Zabbix instance
- Bug Fixes
  + ZBXNEXT-4941 changed overflow statements to execute one
    by one for Oracle for better performance
  + ZBX-15664 fixed "Undefined index" errors on maps with enabled automatic icon mapping
  + ZBX-15667 fixed wrong default Zabbix server status for new installation
  + ZBX-15512 fixed performance issues and significant memory consumption on
    several pages which contains host popup menus
  + ZBX-15512 fixed performance issues in "Problems by severity" widget
  + ZBX-15593 fixed database upgrade patch to stop upgrade on commit failure
  + ZBX-15611 fixed crash in configuration syncer when there are groups with
    same name and when removing preprocessing steps from item
  + ZBX-15242 fixed value trimming and duplicate catching in SVG graph pattern fields
  + ZBX-15250 fixed selection box height calculation in classic graph
  + ZBX-15316 fixed problem with socket inheritance preventing Windows
    agent from restarting under certain circumstances
  + ZBX-15379 fixed -Wimplicit-fallthrough warnings when compiling with GCC 7 and -Wextra
  + ZBX-15179 fixed when message about blocking user login is displayed only on next login attempt
  + ZBX-15494 fixed handling numbers that written in scientific notation
  + ZBX-15533 fixed cutting and trimming event tags and values
  + ZBX-15442 fixed reporting idle time in datasender's process state information
  + ZBX-15424 fixed when multiselect doesn't trim values and recognizes
    untrimmed values as new ones
  + ZBX-14644 fixed maintenance time periods "start_date" field being
    reset to "1920" instead of DB default value when updating via edit form
  + ZBX-15271 added link to documentation in all man pages
  + ZBX-15422 fixed SQL errors when linked template have item prototype with equal key as host item
  + ZBX-15456 fixed incorrect style property in Monitoring->Problems; removed unused id from filter form
* Wed Feb  6 2019 boris@steki.net
- updated to latest release 4.0.4
- New Features and Improvements
  + ZBXNEXT-4872 reworked SVG graph x-axis timeline
  + ZBXNEXT-4873 implemented single dot datasets to be drawn as points
  in line vector graphs
  + ZBX-14876 added a new optional parameter <regex_excl_dir> to
    items vfs.dir.size[] and vfs.dir.count[]
  + ZBXNEXT-4792 added column "Latest values" in Monitoring->Problems and Dashboard
  + ZBX-15202 implemented widget pausing methods in dashboard; made graph widget
    paused when using selection box or opening a tooltip
- Bug Fixes
  + ZBX-15412 fixed Name column overlaps the Application column in the Template view
  + ZBXNEXT-4872 reverted SVG graph timeline changes to previous state
  + ZBX-15577 fixed restricted user access to the host name when calling host_screen
  + ZBX-13335 fixed low performance with linkage of items and item prototypes to a lot of hosts
  + ZBX-15435 fixed "Undefined index" errors in the "Problems" widget with multiple active
    maintenances which part of these are inaccessible
  + ZBX-15417 changed vmware collector to perform datastore configuration refresh only when
    directly monitoring ESXi version lower than v6.0
  + ZBX-14896 fixed low performance of the SQL statement when link template to many hosts
  + ZBX-15220 fixed displaying of last value for values received in the same second
  + ZBX-15451 fixed event correlation when "Event tag pair" condition is used and
    tag contains special characters
  + ZBX-15460 reset agent availability when host status changes, e.g., when host gets disabled
  + ZBX-15331 updated LLD item creation/updating error messages
  + ZBX-15465 removed html non-breaking space from visiblity checkbox labels
  + ZBX-15307 fixed upper level maps positioning in Monitoring Map screen
  + ZBX-15428 improved regular expression performance by studying compiled pattern
  + ZBX-11761 added warnings in case of TLS identity mismatch
  + ZBX-15373 fixed removal of trigger when deleting discovered item; fixed removal of
    dependent child items when removing master item
  + ZBX-14613 fixed hostgroup.delete and host.delete API methods to validate maintenance constraint
  + ZBX-14863 fixed authentication settings form of LDAP anonymous binding
  + ZBX-15374 fixed SQL and PHP errors on chart3.php page
  + ZBX-15301 fixed monotonous lag behind in Windows "system.localtime"
  + ZBX-15377 fixed error messages for arrays in GET parameters
  + ZBX-15369 fixed "Undefined index: label" in map.update() method
  + ZBX-15376 fixed "Undefined index: refresh" on several pages with disabled guest user
  + ZBX-15375 fixed web scenario step name can consist only of whitespaces
  + ZBX-15375 fixed undefined index on Web scenario configuration page
  + ZBX-15372 fixed SQL and PHP errors on "Slide shows" page when enter slides.php witout GET parameters
  + ZBX-15359 fixed undefined index in maintenance.create and maintenance.update API calls
  + ZBX-15358 fixed undefined index in configuration.import API call without one or several rules
  + ZBX-15355 fixed undefined index in configuration.import API call
  + ZBX-14926 fixed empty "inventory" property being returned by API if inventory mode is disabled
  + ZBX-15354 fixed undefined index in API calls without "auth" parameter
  + ZBX-15399 fixed IPv4 connections not being accepted when IPv6 mask is used
  + ZBX-14331 fixed error allowing users to change type of a host interface that already has items attached
  + ZBX-15254 fixed incorrect matching string highlight in multiselect autocomplete box
  + ZBX-15136 fixed displaying 'Plain text' on the dashboard as html
  + ZBX-15313 fixed unit suffix support in calculated item expressions
  + ZBX-15224 fixed failed query errors when receiving non UTF-8 history values
  + ZBX-14592 fixed calculation of SLA and availability report when problem has negative duration
  + ZBX-13804 fixed generic popup form submission
  + ZBX-15156 fixed undefined offset error in host screen with web item
  + ZBX-14980 fixed problem with filter by itemids and hostids in history.get
  + ZBX-14624 fixed agent collector not releasing connection to missing/removed disk devices
  + ZBX-15279 fixed handling of LLD processing errors that should have resulted in not supported LLD rule state
  + ZBX-15241 fixed escaping regexp symbols in preprocessing output parameter when creating item by LLD
  + ZBX-14604 fixed displaying of the graph name on screens
  + ZBXNEXT-4588 renamed 'display options' tab to 'displaying options'; fixed multiple layout issues, footnote in hint-box,
    field value handling, calculation of mouse position, multiple issues related with Y axis and problem styling
  + ZBX-15159 fixed existing context menu closing when new one is opened
  + ZBX-15233 renamed fuzzytime() function description in dropdown list
  + ZBX-12801 excluded zabbix_sender.dll from MS Windows builds with TLS
  + ZBXNEXT-4883 fixed when trigger in problem state hides all dependent triggers in history view
  + ZBX-15260 improved misleading warning message when agent fails to find log file during processing logrt[] item
  + ZBX-15258 fixed update interval of "Zabbix queue" item in server's template to be consistent with proxy template,
    added missing units in proxy template
  + ZBX-15225 improved handling of timeouts in "vfs.dir.size" and "vfs.dir.count" items on Windows agent
  + ZBX-15333 fixed zoomout on doubleclick in graph widget
  + ZBX-15236 fixed display parent host groups without hosts in multiselect
  + ZBX-15206 fixed deprecated net-snmp attribute
  + ZBX-15067 fixed configuration sync of interfaces without hosts
  + ZBX-15238 fixed updating nextcheck time in discovery rules to
    avoid overlaps between discovery executions
  + ZBX-13673 fixed regexp validation when pattern contain slash character
  + ZBX-14528 fixed incorrect keycode handling in multiselect input fields
  + ZBX-15124 fixed trigger overview behavior when show "any"
  + ZBX-14648 ixed performance with deletion of item in template linked to many hosts
  + ZBX-9011 added new LLD macros for vmware HV low-level discovery
  + ZBX-15105 fixed colorpicker tooltip update
  + ZBX-14928 fixed "check now" being executed for active items and templates
  + ZBX-15153 fixed custom interval validation; fixed parsing of custom
    intervals when user macros context contains forward slash
  + ZBX-15069 fixed community default value in edit scenario
  + ZBX-9038 fixed memory of performance counters consumed during vmware update
  + ZBX-8383 updated Tomcat template for compatibility with recent Tomcat versions
  + ZBX-15078 fixed API authentication for ldap users having gui access disabled
  + ZBX-14880 fixed misleading ldap authentication error messages
  + ZBX-14877 fixed style of disabled action on high contrast theme
  + ZBX-14606 removed strict-transport-security header from frontend
  + ZBX-15020 fixed negative time selector offset when selecting time range in graph
  + ZBX-14977 fixed creation of unneeded database record if host prototype inventory
    mode is disabled; fixed validation for host and host prototype inventory mode
  + ZBX-15146 fixed SQL error occurred when too long IP address is attempted to be written in database
  + ZBX-15148 fixed web scenario item selection in SVG graph widget
  + ZBX-15107 fixed error handling in logrt[] items if regular expression for file name is not valid
  + ZBX-14800 fixed resolving of functional macros in graph widget name
  + ZBX-15200 fixed host, trigger and item count calculation; fixed required performance calculation
  + ZBX-15158 fixed graph name for cache usage in proxy and server templates
  + ZBX-15178 fixed wrong behaviour when referencing unexisting capture groups
    in item regexp preprocessing, general pcre code improvements
* Thu Nov 29 2018 boris@steki.net
- updated to latest release 4.0.2
- New Features and Improvements
  + ZBXNEXT-3848 added validation of update interval, custom interval,
    history storage period and trend storage period in low-level discovery
  + ZBXNEXT-4841 removed hardcoded locations for iconv.h and pthread.h;
    thanks to Helmut Grohne for the patch
  + ZBXNEXT-3047 fixed compilation errors on Windows platform with
    static OpenSSL libraries
  + ZBXNEXT-4836 added license information and OpenSSL linking exception
    to README file, show crypto library version when started with '-V'
  + ZBXNEXT-4725 added filter fields to select templates and hosts by directly linked templates;
    made proxy filter field visible in configuration hosts field
  + ZBXNEXT-4796 added 'fullscreen' and 'kiosk' URL arguments to allow to set layout mode via link
  + ZBXNEXT-4782 improve out of memory error message by adding statistics and backtrace;
    improve something impossible has just happened error message by adding backtrace
  + ZBXNEXT-4271 improved escalator performance by using nextcheck index instead of reading whole table
- Bug Fixes
  + ZBX-15171 fixed crash in ODBC when creating JSON from null
    db values, fixed memory leak
  + ZBX-15045 fixed a case where a disable multiselect looks like
    a similar to enabled text field
  + ZBX-14927 fixed filter by host group without real hosts
    in triggers top 100, dashboard widgets, screens
  + ZBX-13662 fixed duplication of file system type in global regular
    expression for file systems discovery
  + ZBX-15036 added system.cpu.util[,guest], system.cpu.util[,guest_nice] to OS Linux template
  + ZBX-15106 improved error messages for item preprocessing, general pcre code improvements
  + ZBX-15095 fixed curl error handling for elasticsearch history backend
  + ZBX-15129 added optional upgrade patches to rename TRIGGER.NAME
    macros to EVENT.NAME in action operation messages and custom scripts
  + ZBX-14858 fixed processing of unlimited vmware maxQueryMetrics value
  + ZBX-14635 fixed rare LLD failures when moving host between groups
  + ZBX-13719 fixed loss of calc_fnc index in graph edit form
  + ZBX-14964 improved escalator performance during maintenance
    by checking paused escalations less frequently
  + ZBX-13793 fixed focus styles on read-only textarea fields
  + ZBX-13009 fixed percentage calculation on availability reports list page
  + ZBX-15138 fixed error message when receiving compressed data over maximum size
  + ZBX-15154 fixed time period parameters in data overview context menu links
  + ZBX-15044 fixed javascript error when zooming classic graph in edit mode
  + ZBX-15044 fixed dashboard initialization in edit mode
  + ZBX-15053 fixed timetamp position in map
  + ZBX-15033 fixed zoom-out and select box for graphs in kiosk mode
  + ZBX-8396 improved source code comments
  + ZBX-14970 fixed wrong media type status upon creation, if chosen status disabled
  + ZBX-14899 fixed wrong net.tcp.listen values on obsolete Linux systems
  + ZBX-14941 fixed issue with autoreconf/automake for source tarball
  + ZBX-15142 fixed time format for vmware performance counters query
  + ZBX-15010 fixed regexp compilation error for patterns with referenced subpatterns
  + ZBX-14724 fixed breadcrumb jumping in IE browser
  + ZBX-15083 fixed API so that macros {TRIGGER.ID} works in map element URLs
  + ZBX-15127 fixed possible crash when communication problem occurred
    in the middle of vmware update
  + ZBX-14396 fixed excessive memory usage during template full clone
  + ZBX-14848 clarified process type names for log level increase/decrease
    in help messages and man pages
  + ZBX-14833 fixed selectHosts option in dservice.get API method
    to return the list of hosts by IP and proxy
  + ZBX-15062 fixed binary heap trying to reallocate slots on every insert
  + ZBX-14805 fixed unauthorized request error when resetting
    filter after enabling/disabling elements
  + ZBX-14789 fixed translations from en_US to en_GB
  + ZBX-14758 fixed encoding for cookie names and values
  + ZBX-15122 fixed possible crash in web monitoring due
    to posts not being reset between steps
  + ZBX-14691 fixed faulty behaviour of mandatory fields in Trigger expression form
  + ZBX-13695 added support of host macros to trapper, HTTP agent item allowed hosts field
  + ZBX-15022 fixed shared memory leak during configuration cache synchronization
  + ZBX-15025 fixed email alerts being sent twice to one recipient
  + ZBX-15006 fixed possibility to link map widget to itself as filter widget
  + ZBX-14886 fixed undefined offset error in Problems by severity widget
  + ZBX-15090 fixed memory leak when validating regular expression
    preprocessing step parameters during LLD
  + ZBX-14625 changed SNMP OID default value to be displayed
    as placeholder instead of text
  + ZBX-14505 fixed compiler warning about incompatible pointer type on 32-bit platform
  + ZBX-1667 fixed error suppression during php ldap module initialization
  + ZBX-13505 fixed link coloring in map when related trigger is not monitored
  + ZBX-15032 fixed sBox position in screen's graph item when dynamic
    item is enabled
  + ZBX-14953 fixed not closed connection with vmware at the end
    of update session via a call to Logout()
  + ZBX-15007 fixed current map refresh in map widget
    right after update widget configuration
  + ZBX-14990 added missing http agent statistic row in queue screen
  + ZBX-14984 fixed missing focus from problem name when opening
    description editing popup in monitoring problems section
  + ZBX-14947 fixed configuration update in administration authentication section
  + ZBX-14974 fixed memory leak in case duplication name
    of the vmware performance counters
  + ZBX-14934 made widget specific javascript files to be loaded with jsLoader
  + ZBX-15094 fixed the potential crash during vmware update
  + ZBX-14966 removed the notes about sqlite from zabbix_server.conf
  + ZBX-14875 fixed discovery and auto registration escalations being kept
    for one hour instead of deleted immediately
  + ZBX-14422 fixed SQL queries being logged when accessing API,
    even if debug mode is disabled
  + ZBX-14905 fixed error reporting for XML import of hosts and templates
  + ZBX-14945 fixed action popup being unclosable after widget refresh,
    fixed debug element being hidden on widget refresh
  + ZBX-14806 changed focus style for radio buttons
  + ZBX-15027 fixed startup failures due to orphaned or zombie processes
    remaining when zabbix daemon is terminated during startup
  + ZBX-14904 fixed possible PHP errors in "Problem hosts" widget
  + ZBX-15057 fixed possible crash when syncing host groups
  + ZBX-14807 fixed selection box for graphs on monitoring screens
  + ZBX-14779 extended support of system.stat[ent], system.stat[cpu,pc],
    system.stat[cpu,ec] on IBM AIX to LPAR type 'dedicated'
  + ZBX-14851 fixed the host visible name in the event details/messages
    from server when using long utf8 text
  + ZBX-14887 fixed max count of records in the single json that proxy can send to the server
  + ZBX-14972 fixed the case where data from non-monitored VMware services are not removed from vmware cache
  + ZBX-14856 added support for OpenSSL 1.1.1
  + ZBX-14971 added note on runtime control with PID numbers larger than 65535 to server,
    proxy and agentd help messages and man pages
  + ZBX-14734 fixed the verification of the assignment of two web checks with the same
    name from different templates to one host
  + ZBX-14749 fixed cloning inherited host prototype on host
  + ZBX-14663 fixed calculation of Y zero position in graph
  + ZBX-14865 fixed "Field "parent_itemid" cannot be set to NULL" error message
    while importing multiple templates
  + ZBX-14925 added support of user language specific url link in support icon,
    supported languages: english as default, japanese, russian
  + ZBX-14854 improved preprocessor worker performance
  + ZBX-14798 fixed incorrect zero rounding in date and time fields
  + ZBX-14954 fixed sql error in escalator when working with Oracle,
    PostgreSQL (less than v9.4) databases
  + ZBX-14952 fixed incorrect translation string in en_US locale
  + ZBX-14757 fixed fields becoming writable upon form refresh in host prototype form
  + ZBX-14915 fixed 'follow redirects' checkbox in web scenario step's dialog
  + ZBX-14811 fixed color of the host name in the title of the Screens
  + ZBX-14776 fixed sorting when changing status of media type
  + ZBX-14711 fixed triggers in trigger overview being filtered by trigger severity and trigger
    status change time instead of problem severity and problem creation time
  + ZBX-14689 fixed updating of the Graph list of host when selecting a group of hosts
  + ZBX-12217 removed links to templates with no permissions for templated triggers,
    trigger prototypes, graphs, graph prototypes, host prototypes and web scenarios
  + ZBX-14861 fixed trigger evaluation result not visible in test dialogue when expression is too long
  + ZBX-14723 fixed zoom button for time selector in IE browser
  + ZBX-14888 fixed table markup on overview and system info pages
  + ZBX-14652 fixed plain text Latest data when selecting more than 1 item
  + ZBX-14618 fixed host prototype status checkbox resets after adding template
  + ZBX-14632 fixed minor typos in comments and tests
  + ZBX-14834 fixed icon misplacement in problem view
  + ZBX-14803 fixed incorrect profile update causing page filter to sometimes show duplicate values
  + ZBX-10784 fixed validation of double/Numeric(float) values
  + ZBX-14727 fixed selection of data for trigger overview and graphs if first drop down entry is "none"
  + ZBX-14615 fixed Java gateway not to mark host unreachable in case of invalid username and password
  + ZBX-14585 fixed JMX endpoint not being included in error message in case of connection errors
  + ZBX-14650 fixed web.page.regexp item parameters description
  + ZBX-14764 fixed crash that could occur when OpenIPMI pollers are configured
  + ZBX-14882 fixed crash in vmware collector when receiving invalid xml
  + ZBX-14908 fixed crash when processing internal trigger events and deleting triggers at the same time
* Tue Oct 16 2018 Boris Manojlovic <boris@steki.net>
- removed support for jabber protocol as iksemel was removed from
  openSUSE:Factory
- fixed configuration paths
* Tue Oct  2 2018 pieter@hollants.com
- initial packaging of zabbix 4.0.0
- inherited patch zabbix-3.0.25-new-m4-pgsql.patch
